severity = brutal
verbose = 8
exclude = Editor::RequireEmacsFileVariables Miscellanea::RequireRcsKeywords Modules::RequireExplicitInclusion Modules::RequireExplicitPackage Tics::ProhibitLongLines Documentation::RequirePODUseEncodingUTF8

[Lax::RequireExplicitPackage::ExceptForPragmata]
allowed_pragmata = perlversion strict warnings utf8

[CodeLayout::RequireTidyCode]
perltidyrc = xt/author/perltidy.rc

[Documentation::PodSpelling]
stop_words = bugtracker Perldoc perldoc annonations PASSed

[Documentation::RequirePodSections]
lib_sections = NAME | VERSION | SYNOPSIS | DESCRIPTION | SUPPORT | AUTHOR | COPYRIGHT AND LICENSE
script_sections = NAME | USAGE | DESCRIPTION | CONFIGURATION | SUPPORT | AUTHOR | COPYRIGHT AND LICENSE

[Subroutines::ProhibitCallsToUndeclaredSubs]
exempt_subs = Any::Moose::any_moose Any::Moose::around Any::Moose::after Any::Moose::has Package::DeprecationManager::deprecated
